@@ -994,6 +994,19 @@ class TestSecurityCompliance:
         
         assert result is not None
     
+    def test_12_1_5_delete_gdpr(self, memory):
+        """12.1.5 deleteGdpr() - Delete GDPR data"""
+        # First export to verify data exists
+        export_result = memory.export_gdpr()
+        assert export_result is not None
+        
+        # Delete GDPR data
+        result = memory.delete_gdpr()
+        
+        assert result is not None
+        assert isinstance(result, dict)
+        assert 'user_id' in result or 'deleted_at' in result
+    
     def test_12_2_set_retention_policy(self, memory):
         """12.2 setRetentionPolicy() - Set retention policy"""
         result = memory.set_retention_policy(
